pub enum FileRef {
ItemHash(ItemHash),
UserDefined {
owner: Address,
reference: String,
},
}Expand description
Explicit file reference, tagged with the owner address for the user-defined case. This is required to perform unambiguous queries on user-defined file references as multiple users may use the same references.
Variants