pub enum AmdSevPolicy {
NoDebug = 1,
NoKeySharing = 2,
SevEs = 4,
NoSend = 8,
Domain = 16,
Sev = 32,
}Variants
NoDebug = 1
Debugging of the guest is disallowed.
NoKeySharing = 2
Sharing keys with other guests is disallowed.
SevEs = 4
SEV-ES is required.
NoSend = 8
Sending the guest to another platform is disallowed.
Domain = 16
The guest must not be transmitted to another platform not in the domain.
Sev = 32
The guest must not be transmitted to another platform that is not SEV capable.