PendingMessage

Struct PendingMessage 

pub struct PendingMessage {
    pub chain: Chain,
    pub sender: Address,
    pub signature: Signature,
    pub message_type: MessageType,
    pub item_type: ItemType,
    pub item_content: String,
    pub item_hash: ItemHash,
    pub time: Timestamp,
    pub channel: Option<Channel>,
}
A signed message ready for submission to the Aleph network.

The item_content field is always present in memory (needed for uploading storage/IPFS content), but the custom Serialize implementation only emits it when item_type == Inline.

Fields

chain: Chainsender: Addresssignature: Signaturemessage_type: MessageTypeitem_type: ItemTypeitem_content: Stringitem_hash: ItemHashtime: Timestampchannel: Option<Channel>