pub struct Timestamp(/* private fields */);Expand description
Timestamp type on the Aleph Cloud network.
Time in Aleph messages is usually represented as a floating-point epoch timestamp. This type keeps the floating point representation for fast serialization/deserialization and to avoid loss of precision, but provides helpers to convert to datetime for human readability.
Implementations
Sourceimpl Timestamp
impl Timestamp
pub fn to_datetime(&self) -> Result<DateTime<Utc>, TimestampError>