Modules
Structs
Enums
- Content
Source - Where to find the content of the message. Note that this is a mix of ItemType / ItemContent if you are used to the Python SDK.
- FileRef
- Explicit file reference, tagged with the owner address for the user-defined case. This is required to perform unambiguous queries on user-defined file references as multiple users may use the same references.
- Message
Content Enum - Content variants for different message types.
- Message
Status - Message
Type - RawFile
Ref - File reference, as deserialized in STORE messages. Does not contain information about the owner.