Module message

Module message 

Re-exports

pub use crate::verify_signature::SignatureVerificationError;

Modules

execution
item_type
pending
unsigned

Structs

AggregateContent
Authorization
A single authorization entry granting a delegate address permission to act on behalf of the owner.
CodeContent
DataContent
Export
ForgetContent
FunctionRuntime
InstanceContent
Message
MessageConfirmation
MessageContent
MessageHeader
A message without its deserialized content.
PostContent
ProgramContent
SecurityAggregateContent
Content of the “security” aggregate.
StoreContent

Enums

AggregateKey
ContentSource
Where to find the content of the message. Note that this is a mix of ItemType / ItemContent if you are used to the Python SDK.
FileRef
Explicit file reference, tagged with the owner address for the user-defined case. This is required to perform unambiguous queries on user-defined file references as multiple users may use the same references.
MessageContentEnum
Content variants for different message types.
MessageStatus
MessageType
MessageVerificationError
RawFileRef
File reference, as deserialized in STORE messages. Does not contain information about the owner.
StorageBackend
StorageEngine
User’s choice of storage backend for file uploads.