Re-exports
pub use crate::verify_signature::SignatureVerificationError;
Modules
Structs
- Aggregate
Content - Authorization
- A single authorization entry granting a delegate address permission to act on behalf of the owner.
- Code
Content - Data
Content - Export
- Forget
Content - Function
Runtime - Instance
Content - Message
- Message
Confirmation - Message
Content - Message
Header - A message without its deserialized content.
- Post
Content - Program
Content - Security
Aggregate Content - Content of the “security” aggregate.
- Store
Content
Enums
- Aggregate
Key - Content
Source - Where to find the content of the message. Note that this is a mix of ItemType / ItemContent if you are used to the Python SDK.
- FileRef
- Explicit file reference, tagged with the owner address for the user-defined case. This is required to perform unambiguous queries on user-defined file references as multiple users may use the same references.
- Message
Content Enum - Content variants for different message types.
- Message
Status - Message
Type - Message
Verification Error - RawFile
Ref - File reference, as deserialized in STORE messages. Does not contain information about the owner.
- Storage
Backend - Storage
Engine - User’s choice of storage backend for file uploads.