Message

Struct Message 

pub struct Message {
    pub chain: Chain,
    pub sender: Address,
    pub signature: Signature,
    pub content_source: ContentSource,
    pub item_hash: ItemHash,
    pub confirmations: Vec<MessageConfirmation>,
    pub time: Timestamp,
    pub channel: Option<Channel>,
    pub message_type: MessageType,
    pub content: MessageContent,
}

Fields

chain: Chain

Blockchain used for this message.

sender: Address

Sender address.

signature: Signature

Cryptographic signature of the message by the sender.

content_source: ContentSource

Content of the message as created by the sender. Can either be inline or stored on Aleph Cloud.

item_hash: ItemHash

Hash of the content (SHA2-256).

confirmations: Vec<MessageConfirmation>

List of confirmations for the message.

time: Timestamp

Unix timestamp or datetime when the message was published.

channel: Option<Channel>

Channel of the message, one application ideally has one channel.

message_type: MessageType

Message type. (aggregate, forget, instance, post, program, store).

content: MessageContent

Message content.

Implementations

Source

impl Message

pub fn content(&self) -> &MessageContentEnum

pub fn confirmed(&self) -> bool

pub fn sender(&self) -> &Address

Returns the address of the sender of the message. Note that the sender is not necessarily the owner of the resources, as the owner may have delegated their authority to create specific resources through the permission system.

pub fn owner(&self) -> &Address

Returns the address of the owner of the resources.

pub fn sent_at(&self) -> &Timestamp

Returns the time at which the message was sent. Notes:

  • This value is signed by the sender and should not be trusted accordingly.
  • We prefer content.time over time as time is not part of the signed payload.
pub fn confirmed_at(&self) -> Option<&Timestamp>

Returns the earliest confirmation time of the message.